@@ -106,8 +106,6 @@ class PMA_Header
 
     /**
      * Creates a new class instance
-     *
-     * @return new PMA_Header object
      */
     public function __construct()
     {
@@ -151,10 +149,9 @@ class PMA_Header
         if (isset($GLOBALS['db'])) {
             $params['db'] = $GLOBALS['db'];
         }
-
         $this->_scripts->addFile('jquery/jquery-1.8.3.min.js');
         $this->_scripts->addFile(
-            'whitelist.php' . PMA_generate_common_url($params), false, true
+            'whitelist.php' . PMA_URL_getCommon($params), false, true
         );
         $this->_scripts->addFile('ajax.js');
         $this->_scripts->addFile('keyhandler.js');
@@ -174,11 +171,15 @@ class PMA_Header
         }
 
         $this->_scripts->addFile('rte.js');
+        if ($GLOBALS['cfg']['SendErrorReports'] !== 'never') {
+            $this->_scripts->addFile('tracekit/tracekit.js');
+            $this->_scripts->addFile('error_report.js');
+        }
 
         // Here would not be a good place to add CodeMirror because
         // the user preferences have not been merged at this point
 
-        $this->_scripts->addFile('messages.php' . PMA_generate_common_url($params));
+        $this->_scripts->addFile('messages.php' . PMA_URL_getCommon($params));
         // Append the theme id to this url to invalidate
         // the cache on a theme change. Though this might be
         // unavailable for fatal errors.
@@ -190,6 +191,7 @@ class PMA_Header
         $this->_scripts->addFile(
             'get_image.js.php?theme=' . $theme_id
         );
+        $this->_scripts->addFile('doclinks.js');
         $this->_scripts->addFile('functions.js');
         $this->_scripts->addFile('navigation.js');
         $this->_scripts->addFile('indexes.js');
@@ -208,7 +210,7 @@ class PMA_Header
         $db = ! empty($GLOBALS['db']) ? $GLOBALS['db'] : '';
         $table = ! empty($GLOBALS['table']) ? $GLOBALS['table'] : '';
         return array(
-            'common_query' => PMA_generate_common_url('', '', '&'),
+            'common_query' => PMA_URL_getCommon('', '', '&'),
             'opendb_url' => $GLOBALS['cfg']['DefaultTabDatabase'],
             'safari_browser' => PMA_USR_BROWSER_AGENT == 'SAFARI' ? 1 : 0,
             'querywindow_height' => $GLOBALS['cfg']['QueryWindowHeight'],
@@ -365,7 +367,8 @@ class PMA_Header
                 // so we can conditionally add CodeMirror
                 if ($GLOBALS['cfg']['CodemirrorEnable']) {
                     $this->_scripts->addFile('codemirror/lib/codemirror.js');
-                    $this->_scripts->addFile('codemirror/mode/mysql/mysql.js');
+                    $this->_scripts->addFile('codemirror/mode/sql/sql.js');
+                    $this->_scripts->addFile('codemirror/addon/runmode/runmode.js');
                 }
                 if ($this->_userprefsOfferImport) {
                     $this->_scripts->addFile('config.js');
@@ -378,10 +381,12 @@ class PMA_Header
                 }
                 // Include possible custom headers
                 if (file_exists(CUSTOM_HEADER_FILE)) {
+                    $retval .= '<div id="pma_header">';
                     ob_start();
                     include CUSTOM_HEADER_FILE;
                     $retval .= ob_get_contents();
                     ob_end_clean();
+                    $retval .= '</div>';
                 }
                 // offer to load user preferences from localStorage
                 if ($this->_userprefsOfferImport) {
@@ -396,9 +401,8 @@ class PMA_Header
                 $retval .= $this->_getWarnings();
                 if ($this->_menuEnabled && $GLOBALS['server'] > 0) {
                     $retval .= $this->_menu->getDisplay();
-                    $pagetop_link = '<a id="goto_pagetop" href="#" title="%s">%s</a>';
                     $retval .= sprintf(
-                        $pagetop_link,
+                        '<a id="goto_pagetop" href="#" title="%s">%s</a>',
                         __('Click on the bar to scroll to top of page'),
                         PMA_Util::getImage('s_top.png')
                     );
@@ -459,19 +463,44 @@ class PMA_Header
          */
         $GLOBALS['now'] = gmdate('D, d M Y H:i:s') . ' GMT';
         if (! defined('TESTSUITE')) {
+            $use_captcha = (
+                !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
+                && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
+            );
             /* Prevent against ClickJacking by disabling framing */
             if (! $GLOBALS['cfg']['AllowThirdPartyFraming']) {
                 header(
                     'X-Frame-Options: DENY'
                 );
             }
+            header(
+                "Content-Security-Policy: default-src 'self' "
+                . ($use_captcha ? 'https://www.google.com ' : ' ')
+                . $GLOBALS['cfg']['CSPAllow'] . ';'
+                . "script-src 'self' 'unsafe-inline' 'unsafe-eval' "
+                . ($use_captcha ? 'https://www.google.com ' : ' ')
+                . ";"
+                . "style-src 'self' 'unsafe-inline' "
+                . ($use_captcha ? 'https://www.google.com ' : ' ')
+                . $GLOBALS['cfg']['CSPAllow']
+                . ";"
+                . "img-src 'self' data: "
+                . $GLOBALS['cfg']['CSPAllow']
+                . ($https ? "" : $mapTilesUrls)
+                // for reCAPTCHA
+                . ($use_captcha ? ' https://www.google.com' : ' ')
+                . ";"
+            );
             header(
                 "X-Content-Security-Policy: default-src 'self' "
+                . ($use_captcha ? 'https://www.google.com ' : ' ')
                 . $GLOBALS['cfg']['CSPAllow'] . ';'
                 . "options inline-script eval-script;"
                 . "img-src 'self' data: "
                 . $GLOBALS['cfg']['CSPAllow']
                 . ($https ? "" : $mapTilesUrls)
+                // for reCAPTCHA
+                . ($use_captcha ? ' https://www.google.com' : ' ')
                 . ";"
             );
             if (PMA_USR_BROWSER_AGENT == 'SAFARI'
@@ -479,24 +508,33 @@ class PMA_Header
             ) {
                 header(
                     "X-WebKit-CSP: allow 'self' "
+                    . ($use_captcha ? 'https://www.google.com ' : ' ')
                     . $GLOBALS['cfg']['CSPAllow'] . ';'
                     . "options inline-script eval-script;"
                     . "img-src 'self' data: "
                     . $GLOBALS['cfg']['CSPAllow']
                     . ($https ? "" : $mapTilesUrls)
+                    // for reCAPTCHA
+                    . ($use_captcha ? ' https://www.google.com' : ' ')
                     . ";"
                 );
             } else {
                 header(
                     "X-WebKit-CSP: default-src 'self' "
+                    . ($use_captcha ? 'https://www.google.com ' : ' ')
                     . $GLOBALS['cfg']['CSPAllow'] . ';'
                     . "script-src 'self' "
+                    . ($use_captcha ? 'https://www.google.com ' : ' ')
                     . $GLOBALS['cfg']['CSPAllow']
                     . " 'unsafe-inline' 'unsafe-eval';"
-                    . "style-src 'self' 'unsafe-inline';"
+                    . "style-src 'self' 'unsafe-inline' "
+                    . ($use_captcha ? 'https://www.google.com ' : ' ')
+                    . ';'
                     . "img-src 'self' data: "
                     . $GLOBALS['cfg']['CSPAllow']
                     . ($https ? "" : $mapTilesUrls)
+                    // for reCAPTCHA
+                    . ($use_captcha ? ' https://www.google.com' : ' ')
                     . ";"
                 );
             }
@@ -520,7 +558,10 @@ class PMA_Header
         $dir  = $GLOBALS['text_dir'];
 
         $retval  = "<!DOCTYPE HTML>";
-        $retval .= "<html lang='$lang' dir='$dir'>";
+        $retval .= "<html lang='$lang' dir='$dir' class='";
+        $retval .= strtolower(PMA_USR_BROWSER_AGENT) . " ";
+        $retval .= strtolower(PMA_USR_BROWSER_AGENT)
+            . intval(PMA_USR_BROWSER_VER) . "'>";
 
         return $retval;
     }
@@ -554,7 +595,7 @@ class PMA_Header
             . 'type="image/x-icon" />';
         // stylesheets
         $basedir    = defined('PMA_PATH_TO_BASEDIR') ? PMA_PATH_TO_BASEDIR : '';
-        $common_url = PMA_generate_common_url(array('server' => $GLOBALS['server']));
+        $common_url = PMA_URL_getCommon(array('server' => $GLOBALS['server']));
         $theme_id   = $GLOBALS['PMA_Config']->getThemeUniqueValue();
         $theme_path = $GLOBALS['pmaThemePath'];
 
@@ -660,11 +701,14 @@ class PMA_Header
     private function _addRecentTable($db, $table)
     {
         $retval = '';
-        if ($this->_menuEnabled && strlen($table) && $GLOBALS['cfg']['NumRecentTables'] > 0) {
+        if ($this->_menuEnabled
+            && strlen($table)
+            && $GLOBALS['cfg']['NumRecentTables'] > 0
+        ) {
             $tmp_result = PMA_RecentTable::getInstance()->add($db, $table);
             if ($tmp_result === true) {
                 $params  = array('ajax_request' => true, 'recent_table' => true);
-                $url     = 'index.php' . PMA_generate_common_url($params);
+                $url     = 'index.php' . PMA_URL_getCommon($params);
                 $retval  = '<a class="hide" id="update_recent_tables"';
                 $retval .= ' href="' . $url . '"></a>';
             } else {
