@@ -56,7 +56,9 @@ class PMA_Scripts
         foreach ($files as $value) {
             if (strpos($value['filename'], "?") === false) {
                 $include = true;
-                if ($value['conditional_ie'] !== false && PMA_USR_BROWSER_AGENT === 'IE') {
+                if ($value['conditional_ie'] !== false
+                    && PMA_USR_BROWSER_AGENT === 'IE'
+                ) {
                     if ($value['conditional_ie'] === true) {
                         $include = true;
                     } else if ($value['conditional_ie'] == PMA_USR_BROWSER_VER) {
@@ -66,27 +68,23 @@ class PMA_Scripts
                     }
                 }
                 if ($include) {
-                    $params[] = "scripts[]=" . $value['filename'];
+                    $scripts[] = "scripts[]=" . $value['filename'];
                 }
             } else {
                 if ($value['before_statics'] === true) {
-                    $first_dynamic_scripts .= "<script type='text/javascript' src='js/" . $value['filename'] . "'></script>";
+                    $first_dynamic_scripts .= "<script type='text/javascript' src='js/"
+                        . $value['filename'] . "'></script>";
                 } else {
-                    $dynamic_scripts .= "<script type='text/javascript' src='js/" . $value['filename'] . "'></script>";
+                    $dynamic_scripts .= "<script type='text/javascript' src='js/"
+                        . $value['filename'] . "'></script>";
                 }
             }
         }
-        $static_scripts = '';
-        // Using chunks of 10 files to avoid too long URLs
-        $script_chunks = array_chunk($params, 10);
-        foreach ($script_chunks as $script_chunk) {
-            $url = 'js/get_scripts.js.php?' . implode('&', $script_chunk);
-
-            $static_scripts .= sprintf(
-                '<script type="text/javascript" src="%s"></script>',
-                htmlspecialchars($url)
-            );
-        }
+        $static_scripts = sprintf(
+            '<script type="text/javascript" '
+            . 'src="js/get_scripts.js.php%s&%s"></script>',
+            PMA_URL_getCommon(array(), 'none'), implode("&", $scripts)
+        );
         return $first_dynamic_scripts . $static_scripts . $dynamic_scripts;
     }
 
@@ -110,7 +108,7 @@ class PMA_Scripts
      * @param bool   $conditional_ie Whether to wrap the script tag in
      *                               conditional comments for IE
      * @param bool   $before_statics Whether this dynamic script should be
-     *                               include before the static ones
+     *                               included before the static ones
      *
      * @return void
      */
