@@ -3,7 +3,7 @@
 /**
  * Form edit view
  *
- * @package PhpMyAdmin-setup
+ * @package PhpMyAdmin-Setup
  */
 
 if (!defined('PHPMYADMIN')) {
@@ -22,13 +22,13 @@ require './libraries/config/setup.forms.php';
 $formset_id = filter_input(INPUT_GET, 'formset');
 $mode = filter_input(INPUT_GET, 'mode');
 if (! isset($forms[$formset_id])) {
-    die(__('Incorrect formset, check $formsets array in setup/frames/form.inc.php'));
+    PMA_fatalError(__('Incorrect formset, check $formsets array in setup/frames/form.inc.php'));
 }
 
 if (isset($GLOBALS['strConfigFormset_' . $formset_id])) {
     echo '<h2>' . $GLOBALS['strConfigFormset_' . $formset_id] . '</h2>';
 }
-$form_display = new FormDisplay();
+$form_display = new FormDisplay($GLOBALS['ConfigFile']);
 foreach ($forms[$formset_id] as $form_name => $form) {
     $form_display->registerForm($form_name, $form);
 }
